@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_applicationautoscaling._jsii
 import aws_cdk.aws_cloudwatch._jsii
@@ -24,7 +24,7 @@ import aws_cdk.cx_api._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/aws-lambda", "1.63.0", __name__[0:-6], "aws-lambda@1.63.0.jsii.tgz"
+    "@aws-cdk/aws-lambda", "1.65.0", __name__[0:-6], "aws-lambda@1.65.0.jsii.tgz"
 )
 
 __all__ = [
